# coding: utf8
from __future__ import unicode_literals

import pytest
from spacy.attrs import IS_ALPHA
from spacy.lang.en import English


@pytest.mark.parametrize(
    "sentence",
    [
        "The story was to the effect that a young American student recently called on Professor Christlieb with a letter of introduction.",
        "The next month Barry Siddall joined Stoke City on a free transfer, after Chris Pearce had established himself as the Vale's #1.",
        "The next month Barry Siddall joined Stoke City on a free transfer, after Chris Pearce had established himself as the Vale's number one",
        "Indeed, making the one who remains do all the work has installed him into a position of such insolent tyranny, it will take a month at least to reduce him to his proper proportions.",
        "It was a missed assignment, but it shouldn't have resulted in a turnover ...",
    ],
)
def test_issue3869(sentence):
    """Test that the Doc's count_by function works consistently"""
    nlp = English()
    doc = nlp(sentence)

    count = 0
    for token in doc:
        count += token.is_alpha

    assert count == doc.count_by(IS_ALPHA).get(1, 0)



from ..vocab cimport Vocab
from ..typedefs cimport hash_t
from ..structs cimport MorphAnalysisC


cdef class MorphAnalysis:
    cdef readonly Vocab vocab
    cdef hash_t key
    cdef MorphAnalysisC c



# coding: utf8
from __future__ import unicode_literals

from .stop_words import STOP_WORDS
from .lex_attrs import LEX_ATTRS
from .tag_map import TAG_MAP
from .tokenizer_exceptions import TOKENIZER_EXCEPTIONS
from .punctuation import TOKENIZER_PREFIXES, TOKENIZER_INFIXES
from .punctuation import TOKENIZER_SUFFIXES
from .lemmatizer import DutchLemmatizer
from ..tokenizer_exceptions import BASE_EXCEPTIONS
from ..norm_exceptions import BASE_NORMS
from ...language import Language
from ...lookups import Lookups
from ...attrs import LANG, NORM
from ...util import update_exc, add_lookups


class DutchDefaults(Language.Defaults):
    lex_attr_getters = dict(Language.Defaults.lex_attr_getters)
    lex_attr_getters.update(LEX_ATTRS)
    lex_attr_getters[LANG] = lambda text: "nl"
    lex_attr_getters[NORM] = add_lookups(
        Language.Defaults.lex_attr_getters[NORM], BASE_NORMS
    )
    tokenizer_exceptions = update_exc(BASE_EXCEPTIONS, TOKENIZER_EXCEPTIONS)
    stop_words = STOP_WORDS
    tag_map = TAG_MAP
    prefixes = TOKENIZER_PREFIXES
    infixes = TOKENIZER_INFIXES
    suffixes = TOKENIZER_SUFFIXES

    @classmethod
    def create_lemmatizer(cls, nlp=None, lookups=None):
        if lookups is None:
            lookups = Lookups()
        return DutchLemmatizer(lookups)


class Dutch(Language):
    lang = "nl"
    Defaults = DutchDefaults


__all__ = ["Dutch"]



# coding: utf8
from __future__ import unicode_literals

from ...symbols import LEMMA, PRON_LEMMA


_coordinating_conjunctions = [
    "ar",
    "arba",
    "bei",
    "beigi",
    "bet",
    "betgi",
    "ir",
    "kadangi",
    "kuo",
    "ne",
    "o",
    "tad",
    "tai",
    "tačiau",
    "tegul",
    "tik",
    "visgi",
]

_subordinating_conjunctions = [
    "jei",
    "jeigu",
    "jog",
    "kad",
    "kai",
    "kaip",
    "kol",
    "lyg",
    "nebent",
    "negu",
    "nei",
    "nes",
    "nors",
    "tarsi",
    "tuo",
    "užuot",
]

MORPH_RULES = {
    "Cg": dict(
        [(word, {"POS": "CCONJ"}) for word in _coordinating_conjunctions]
        + [(word, {"POS": "SCONJ"}) for word in _subordinating_conjunctions]
    ),
    "Pg--an": {
        "keletą": {LEMMA: PRON_LEMMA, "POS": "PRON", "Case": "Acc", "PronType": "Ind"},
        "save": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "PronType": "Prs",
            "Reflex": "Yes",
        },
    },
    "Pg--dn": {
        "sau": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "PronType": "Prs",
            "Reflex": "Yes",
        }
    },
    "Pg--gn": {
        "keleto": {LEMMA: PRON_LEMMA, "POS": "PRON", "Case": "Gen", "PronType": "Ind"},
        "savo": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "PronType": "Prs",
            "Reflex": "Yes",
        },
        "savęs": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "PronType": "Prs",
            "Reflex": "Yes",
        },
    },
    "Pg--in": {
        "savimi": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "PronType": "Prs",
            "Reflex": "Yes",
        }
    },
    "Pg--nn": {
        "keletas": {LEMMA: PRON_LEMMA, "POS": "PRON", "Case": "Nom", "PronType": "Ind"}
    },
    "Pg-dnn": {
        "mudu": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Number": "Dual",
            "Person": "1",
            "PronType": "Prs",
        }
    },
    "Pg-pa-": {
        "jus": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Number": "Plur",
            "Person": "2",
            "PronType": "Prs",
        }
    },
    "Pg-pan": {
        "jus": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Number": "Plur",
            "Person": "2",
            "PronType": "Prs",
        },
        "mus": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Number": "Plur",
            "Person": "1",
            "PronType": "Prs",
        },
    },
    "Pg-pdn": {
        "jums": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Number": "Plur",
            "Person": "2",
            "PronType": "Prs",
        },
        "mums": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Number": "Plur",
            "Person": "1",
            "PronType": "Prs",
        },
    },
    "Pg-pgn": {
        "jūsų": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Number": "Plur",
            "Person": "2",
            "PronType": "Prs",
        },
        "mūsų": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Number": "Plur",
            "Person": "1",
            "PronType": "Prs",
        },
    },
    "Pg-pin": {
        "jumis": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "Number": "Plur",
            "Person": "2",
            "PronType": "Prs",
        },
        "mumis": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "Number": "Plur",
            "Person": "1",
            "PronType": "Prs",
        },
    },
    "Pg-pln": {
        "jumyse": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Loc",
            "Number": "Plur",
            "Person": "2",
            "PronType": "Prs",
        }
    },
    "Pg-pnn": {
        "jūs": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Number": "Plur",
            "Person": "2",
            "PronType": "Prs",
        },
        "mes": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Number": "Plur",
            "Person": "1",
            "PronType": "Prs",
        },
    },
    "Pg-san": {
        "mane": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Number": "Sing",
            "Person": "1",
            "PronType": "Prs",
        },
        "tave": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Number": "Sing",
            "Person": "2",
            "PronType": "Prs",
        },
    },
    "Pg-sd-": {
        "tau": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Number": "Sing",
            "Person": "2",
            "PronType": "Prs",
        }
    },
    "Pg-sdn": {
        "man": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Number": "Sing",
            "Person": "1",
            "PronType": "Prs",
        },
        "sau": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Number": "Sing",
            "PronType": "Prs",
            "Reflex": "Yes",
        },
        "tau": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Number": "Sing",
            "Person": "2",
            "PronType": "Prs",
        },
    },
    "Pg-sgn": {
        "mano": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Number": "Sing",
            "Person": "1",
            "PronType": "Prs",
        },
        "manęs": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Number": "Sing",
            "Person": "1",
            "PronType": "Prs",
        },
        "tavo": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Number": "Sing",
            "Person": "2",
            "PronType": "Prs",
        },
        "tavęs": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Number": "Sing",
            "Person": "2",
            "PronType": "Prs",
        },
    },
    "Pg-sin": {
        "manimi": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "Number": "Sing",
            "Person": "1",
            "PronType": "Prs",
        },
        "tavim": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "Number": "Sing",
            "Person": "2",
            "PronType": "Prs",
        },
        "tavimi": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "Number": "Sing",
            "Person": "2",
            "PronType": "Prs",
        },
    },
    "Pg-sln": {
        "manyje": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Loc",
            "Number": "Sing",
            "Person": "1",
            "PronType": "Prs",
        },
        "tavyje": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Loc",
            "Number": "Sing",
            "Person": "2",
            "PronType": "Prs",
        },
    },
    "Pg-snn": {
        "aš": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Number": "Sing",
            "Person": "1",
            "PronType": "Prs",
        },
        "tu": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Number": "Sing",
            "Person": "2",
            "PronType": "Prs",
        },
    },
    "Pgf-an": {
        "kelias": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Fem",
            "PronType": "Ind",
        }
    },
    "Pgf-dn": {
        "kelioms": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Gender": "Fem",
            "PronType": "Ind",
        }
    },
    "Pgf-nn": {
        "kelios": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Fem",
            "PronType": "Ind",
        }
    },
    "Pgfdn-": {
        "abi": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Dual",
            "PronType": "Ind",
        }
    },
    "Pgfpan": {
        "jas": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Plur",
            "Person": "3",
            "PronType": "Prs",
        },
        "kelias": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "kitas": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "kokias": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Int",
        },
        "kurias": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Int",
        },
        "savas": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "tas": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Dem",
        },
        "tokias": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Dem",
        },
    },
    "Pgfpdn": {
        "joms": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Gender": "Fem",
            "Number": "Plur",
            "Person": "3",
            "PronType": "Prs",
        },
        "kitoms": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "kurioms": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Dat",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Int",
        },
        "tokioms": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Dat",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Dem",
        },
    },
    "Pgfpgn": {
        "jokių": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Neg",
        },
        "jų": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Plur",
            "Person": "3",
            "PronType": "Prs",
        },
        "kelių": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "kitų": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "kurių": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Int",
        },
        "pačių": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Emp",
        },
        "tokių": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Dem",
        },
        "tų": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Dem",
        },
    },
    "Pgfpin": {
        "jomis": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "Gender": "Fem",
            "Number": "Plur",
            "Person": "3",
            "PronType": "Prs",
        },
        "kitokiomis": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "kitomis": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "kokiomis": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Int",
        },
        "kuriomis": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Int",
        },
        "pačiomis": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Emp",
        },
        "tomis": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Dem",
        },
    },
    "Pgfpln": {
        "jose": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Loc",
            "Gender": "Fem",
            "Number": "Plur",
            "Person": "3",
            "PronType": "Prs",
        },
        "kitose": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Loc",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "kuriose": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Loc",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Int",
        },
        "tokiose": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Loc",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Dem",
        },
        "tose": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Loc",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Dem",
        },
    },
    "Pgfpnn": {
        "jos": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Plur",
            "Person": "3",
            "PronType": "Prs",
        },
        "kitokios": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "kitos": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "kokios": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Int",
        },
        "kurios": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Int",
        },
        "pačios": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Emp",
        },
        "tokios": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Dem",
        },
        "tos": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Plur",
            "PronType": "Dem",
        },
    },
    "Pgfsan": {
        "ją": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Sing",
            "Person": "3",
            "PronType": "Prs",
        },
        "kiekvieną": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Tot",
        },
        "kitokią": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Ind",
        },
        "kitą": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Ind",
        },
        "kokią": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Int",
        },
        "kurią": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Int",
        },
        "pačią": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Emp",
        },
        "tokią": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Dem",
        },
        "tą": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Dem",
        },
    },
    "Pgfsdn": {
        "jai": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Gender": "Fem",
            "Number": "Sing",
            "Person": "3",
            "PronType": "Prs",
        },
        "kiekvienai": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Dat",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Tot",
        },
        "kitai": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Ind",
        },
        "pačiai": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Dat",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Emp",
        },
    },
    "Pgfsgn": {
        "jokios": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Neg",
        },
        "jos": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Sing",
            "Person": "3",
            "PronType": "Prs",
        },
        "kiekvienos": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Tot",
        },
        "kokios": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Int",
        },
        "kurios": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Int",
        },
        "pačios": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Emp",
        },
        "tokios": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Dem",
        },
        "tos": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Dem",
        },
    },
    "Pgfsin": {
        "ja": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "Gender": "Fem",
            "Number": "Sing",
            "Person": "3",
            "PronType": "Prs",
        },
        "kiekviena": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Tot",
        },
        "kita": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Ind",
        },
        "kuria": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Int",
        },
        "ta": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Dem",
        },
        "tokia": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Dem",
        },
    },
    "Pgfsln": {
        "joje": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Loc",
            "Gender": "Fem",
            "Number": "Sing",
            "Person": "3",
            "PronType": "Prs",
        },
        "kiekvienoje": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Loc",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Tot",
        },
        "kitoje": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Loc",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Ind",
        },
        "kurioje": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Loc",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Int",
        },
        "toje": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Loc",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Dem",
        },
        "tokioje": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Loc",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Dem",
        },
    },
    "Pgfsnn": {
        "ji": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Sing",
            "Person": "3",
            "PronType": "Prs",
        },
        "kiekviena": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Tot",
        },
        "kita": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Ind",
        },
        "kokia": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Int",
        },
        "kuri": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Int",
        },
        "pati": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Emp",
        },
        "sava": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Ind",
        },
        "ta": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Dem",
        },
        "tokia": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Dem",
        },
    },
    "Pgfsny": {
        "jinai": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Sing",
            "Person": "3",
            "PronType": "Prs",
        },
        "toji": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Sing",
            "PronType": "Dem",
        },
    },
    "Pgfsny-": {
        "jinai": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Fem",
            "Number": "Sing",
            "Person": "3",
            "PronType": "Prs",
        }
    },
    "Pgm-a-": {
        "kelis": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Masc",
            "PronType": "Ind",
        }
    },
    "Pgm-an": {
        "kelis": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Masc",
            "PronType": "Ind",
        }
    },
    "Pgm-dn": {
        "keliems": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Gender": "Masc",
            "PronType": "Ind",
        }
    },
    "Pgm-gn": {
        "kelių": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Gender": "Masc",
            "PronType": "Ind",
        }
    },
    "Pgm-nn": {
        "keli": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Masc",
            "PronType": "Ind",
        }
    },
    "Pgmdan": {
        "mudu": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Dual",
            "Person": "1",
            "PronType": "Prs",
        }
    },
    "Pgmdgn": {
        "mudviejų": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Dual",
            "Person": "1",
            "PronType": "Prs",
        }
    },
    "Pgmdnn": {
        "jiedu": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Dual",
            "Person": "3",
            "PronType": "Prs",
        },
        "mudu": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Dual",
            "Person": "1",
            "PronType": "Prs",
        },
    },
    "Pgmpan": {
        "juos": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Plur",
            "Person": "3",
            "PronType": "Prs",
        },
        "jus": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Plur",
            "Person": "2",
            "PronType": "Prs",
        },
        "kitus": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "kokius": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Int",
        },
        "kuriuos": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Int",
        },
        "pačius": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Emp",
        },
        "tokius": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Dem",
        },
        "tuos": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Dem",
        },
    },
    "Pgmpan-": {
        "juos": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Plur",
            "Person": "3",
            "PronType": "Prs",
        }
    },
    "Pgmpdn": {
        "jiems": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Gender": "Masc",
            "Number": "Plur",
            "Person": "3",
            "PronType": "Prs",
        },
        "kitiems": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "kuriems": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Dat",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Int",
        },
        "patiems": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Dat",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Emp",
        },
        "tiems": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Dat",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Dem",
        },
    },
    "Pgmpgn": {
        "jokių": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Neg",
        },
        "jų": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Plur",
            "Person": "3",
            "PronType": "Prs",
        },
        "kitų": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "kokių": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Int",
        },
        "kurių": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Int",
        },
        "pačių": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Emp",
        },
        "tokių": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Dem",
        },
        "tų": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Dem",
        },
    },
    "Pgmpin": {
        "jais": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "Gender": "Masc",
            "Number": "Plur",
            "Person": "3",
            "PronType": "Prs",
        },
        "jokiais": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Neg",
        },
        "kitais": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "kokiais": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Int",
        },
        "savais": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "tais": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Dem",
        },
        "tokiais": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Dem",
        },
    },
    "Pgmpln": {
        "juose": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Loc",
            "Gender": "Masc",
            "Number": "Plur",
            "Person": "3",
            "PronType": "Prs",
        },
        "kituose": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Loc",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Ind",
        },
    },
    "Pgmpnn": {
        "jie": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Plur",
            "Person": "3",
            "PronType": "Prs",
        },
        "jūs": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Plur",
            "Person": "2",
            "PronType": "Prs",
        },
        "kiti": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Ind",
        },
        "kokie": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Int",
        },
        "kurie": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Int",
        },
        "patys": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Emp",
        },
        "tie": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Dem",
        },
        "tokie": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Plur",
            "PronType": "Dem",
        },
    },
    "Pgmsan": {
        "jį": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Sing",
            "Person": "3",
            "PronType": "Prs",
        },
        "kiekvieną": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Tot",
        },
        "kitokį": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Ind",
        },
        "kitą": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Ind",
        },
        "kokį": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Int",
        },
        "kurį": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Int",
        },
        "tokį": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Dem",
        },
        "tą": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Acc",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Dem",
        },
    },
    "Pgmsdn": {
        "jam": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Gender": "Masc",
            "Number": "Sing",
            "Person": "3",
            "PronType": "Prs",
        },
        "kiekvienam": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Dat",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Tot",
        },
        "kitam": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Dat",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Ind",
        },
        "kokiam": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Dat",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Int",
        },
        "kuriam": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Dat",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Int",
        },
        "pačiam": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Dat",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Emp",
        },
        "tam": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Dat",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Dem",
        },
    },
    "Pgmsgn": {
        "jo": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Sing",
            "Person": "3",
            "PronType": "Prs",
        },
        "jokio": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Neg",
        },
        "kiekvieno": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Tot",
        },
        "kito": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Ind",
        },
        "kokio": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Int",
        },
        "kurio": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Int",
        },
        "paties": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Emp",
        },
        "savo": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Ind",
        },
        "to": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Dem",
        },
        "tokio": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Gen",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Dem",
        },
    },
    "Pgmsin": {
        "juo": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "Gender": "Masc",
            "Number": "Sing",
            "Person": "3",
            "PronType": "Prs",
        },
        "kitu": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Ins",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Ind",
        },
        "kokiu": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Int",
        },
        "kuriuo": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Int",
        },
        "pačiu": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Emp",
        },
        "tokiu": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Dem",
        },
        "tuo": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Ins",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Dem",
        },
    },
    "Pgmsln": {
        "jame": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Loc",
            "Gender": "Masc",
            "Number": "Sing",
            "Person": "3",
            "PronType": "Prs",
        },
        "kiekvienam": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Loc",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Tot",
        },
        "kokiame": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Loc",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Int",
        },
        "kuriame": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Loc",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Int",
        },
        "tame": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Loc",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Dem",
        },
    },
    "Pgmsnn": {
        "jis": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Sing",
            "Person": "3",
            "PronType": "Prs",
        },
        "joks": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Neg",
        },
        "kiekvienas": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Tot",
        },
        "kitas": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Ind",
        },
        "kitoks": {
            LEMMA: PRON_LEMMA,
            "POS": "PRON",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Ind",
        },
        "koks": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Int",
        },
        "kuris": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Int",
        },
        "pats": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Emp",
        },
        "tas": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Dem",
        },
        "toks": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Dem",
        },
    },
    "Pgmsny": {
        "patsai": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Emp",
        },
        "tasai": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Dem",
        },
        "toksai": {
            LEMMA: PRON_LEMMA,
            "POS": "DET",
            "Case": "Nom",
            "Gender": "Masc",
            "Number": "Sing",
            "PronType": "Dem",
        },
    },
    "Pgn--n": {
        "tai": {LEMMA: PRON_LEMMA, "POS": "DET", "Gender": "Neut", "PronType": "Dem"}
    },
    "Pgnn--n": {
        "tai": {LEMMA: PRON_LEMMA, "POS": "DET", "Gender": "Neut", "PronType": "Dem"}
    },
    "Pgsmdn": {
        "tam": {LEMMA: PRON_LEMMA, "POS": "DET", "Case": "Dat", "PronType": "Dem"}
    },
    "Qg": {"tai": {LEMMA: "tas", "POS": "PART"}},
    "Vgap----n--n--": {
        "esant": {
            LEMMA: "būti",
            "POS": "VERB",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Ger",
        },
        "turint": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Ger",
        },
    },
    "Vgh--pm-n--n--": {
        "būdami": {
            LEMMA: "būti",
            "POS": "VERB",
            "Gender": "Masc",
            "Number": "Plur",
            "Polarity": "POS",
            "VerbForm": "Conv",
        }
    },
    "Vgh--sm-n--n--": {
        "būdamas": {
            LEMMA: "būti",
            "POS": "VERB",
            "Gender": "Masc",
            "Number": "Sing",
            "Polarity": "POS",
            "VerbForm": "Conv",
        }
    },
    "Vgi-----n--n--": {
        "būti": {LEMMA: "būti", "POS": "VERB", "Polarity": "POS", "VerbForm": "Inf"},
        "daryti": {
            LEMMA: "daryti",
            "POS": "VERB",
            "Polarity": "POS",
            "VerbForm": "Inf",
        },
        "turėti": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Polarity": "POS",
            "VerbForm": "Inf",
        },
    },
    "Vgm-1p--n--ns-": {
        "turėtume": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Cnd",
            "Number": "Plur",
            "Person": "1",
            "Polarity": "POS",
            "VerbForm": "Fin",
        }
    },
    "Vgm-2p--n--nm-": {
        "būkite": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Imp",
            "Number": "Plur",
            "Person": "2",
            "Polarity": "POS",
            "VerbForm": "Fin",
        },
        "darykit": {
            LEMMA: "daryti",
            "POS": "VERB",
            "Mood": "Imp",
            "Number": "Plur",
            "Person": "2",
            "Polarity": "POS",
            "VerbForm": "Fin",
        },
        "darykite": {
            LEMMA: "daryti",
            "POS": "VERB",
            "Mood": "Imp",
            "Number": "Plur",
            "Person": "2",
            "Polarity": "POS",
            "VerbForm": "Fin",
        },
        "turėkite": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Imp",
            "Number": "Plur",
            "Person": "2",
            "Polarity": "POS",
            "VerbForm": "Fin",
        },
    },
    "Vgm-2p--n--ns-": {
        "turėtumėte": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Cnd",
            "Number": "Plur",
            "Person": "2",
            "Polarity": "POS",
            "VerbForm": "Fin",
        }
    },
    "Vgm-2s--n--ns-": {
        "turėtum": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Cnd",
            "Number": "Sing",
            "Person": "2",
            "Polarity": "POS",
            "VerbForm": "Fin",
        }
    },
    "Vgm-3---n--ns-": {
        "būtų": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Cnd",
            "Person": "3",
            "Polarity": "POS",
            "VerbForm": "Fin",
        },
        "turėtų": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Cnd",
            "Person": "3",
            "Polarity": "POS",
            "VerbForm": "Fin",
        },
    },
    "Vgm-3p--n--ns-": {
        "būtų": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Cnd",
            "Number": "Plur",
            "Person": "3",
            "Polarity": "POS",
            "VerbForm": "Fin",
        },
        "turėtų": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Cnd",
            "Number": "Plur",
            "Person": "3",
            "Polarity": "POS",
            "VerbForm": "Fin",
        },
    },
    "Vgm-3s--n--ns-": {
        "būtų": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Cnd",
            "Number": "Sing",
            "Person": "3",
            "Polarity": "POS",
            "VerbForm": "Fin",
        },
        "turėtų": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Cnd",
            "Number": "Sing",
            "Person": "3",
            "Polarity": "POS",
            "VerbForm": "Fin",
        },
    },
    "Vgma1p--n--ni-": {
        "turėjom": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "1",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Fin",
        }
    },
    "Vgma1s--n--ni-": {
        "turėjau": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "1",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Fin",
        }
    },
    "Vgma3---n--ni-": {
        "buvo": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Fin",
        },
        "turėjo": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Fin",
        },
    },
    "Vgma3p--n--ni-": {
        "buvo": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Fin",
        },
        "darė": {
            LEMMA: "daryti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Fin",
        },
        "turėjo": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Fin",
        },
    },
    "Vgma3s--n--ni-": {
        "buvo": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Fin",
        },
        "darė": {
            LEMMA: "daryti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Fin",
        },
        "turėjo": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Fin",
        },
    },
    "Vgmf1s--n--ni-": {
        "turėsiu": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "1",
            "Polarity": "POS",
            "Tense": "Fut",
            "VerbForm": "Fin",
        }
    },
    "Vgmf2p--n--ni-": {
        "būsite": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "2",
            "Polarity": "POS",
            "Tense": "Fut",
            "VerbForm": "Fin",
        },
        "darysite": {
            LEMMA: "daryti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "2",
            "Polarity": "POS",
            "Tense": "Fut",
            "VerbForm": "Fin",
        },
        "turėsite": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "2",
            "Polarity": "POS",
            "Tense": "Fut",
            "VerbForm": "Fin",
        },
    },
    "Vgmf3---n--ni-": {
        "bus": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Fut",
            "VerbForm": "Fin",
        }
    },
    "Vgmf3p--n--ni-": {
        "bus": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Fut",
            "VerbForm": "Fin",
        },
        "darys": {
            LEMMA: "daryti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Fut",
            "VerbForm": "Fin",
        },
        "turės": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Fut",
            "VerbForm": "Fin",
        },
    },
    "Vgmf3s--n--ni-": {
        "bus": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Fut",
            "VerbForm": "Fin",
        },
        "turės": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Fut",
            "VerbForm": "Fin",
        },
    },
    "Vgmp1p--n--ni-": {
        "darome": {
            LEMMA: "daryti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "1",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
        "esame": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "1",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
        "turime": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "1",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
    },
    "Vgmp1s--n--ni-": {
        "būnu": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "1",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
        "esu": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "1",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
        "turiu": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "1",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
    },
    "Vgmp2p--n--ni-": {
        "esate": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "2",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
        "turite": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "2",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
    },
    "Vgmp2s--n--ni-": {
        "esi": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "2",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
        "turi": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "2",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
    },
    "Vgmp3---n--ni-": {
        "būna": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
        "turi": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
        "yra": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
    },
    "Vgmp3p--n--ni-": {
        "būna": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
        "daro": {
            LEMMA: "daryti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
        "turi": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
        "yra": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Plur",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
    },
    "Vgmp3s--n--ni-": {
        "būna": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
        "daro": {
            LEMMA: "daryti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
        "turi": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
        "yra": {
            LEMMA: "būti",
            "POS": "VERB",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Fin",
        },
    },
    "Vgmq2s--n--ni-": {
        "turėdavai": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Aspect": "Hab",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "2",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Fin",
        }
    },
    "Vgmq3---n--ni-": {
        "būdavo": {
            LEMMA: "būti",
            "POS": "VERB",
            "Aspect": "Hab",
            "Mood": "Ind",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Fin",
        }
    },
    "Vgmq3s--n--ni-": {
        "turėdavo": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Aspect": "Hab",
            "Mood": "Ind",
            "Number": "Sing",
            "Person": "3",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Fin",
        }
    },
    "Vgp--pfnnnnn-p": {
        "darytinos": {
            LEMMA: "daryti",
            "POS": "VERB",
            "Case": "Nom",
            "Degree": "POS",
            "Gender": "Fem",
            "Number": "Plur",
            "Polarity": "POS",
            "VerbForm": "Part",
        }
    },
    "Vgpa--nann-n-p": {
        "buvę": {
            LEMMA: "būti",
            "POS": "VERB",
            "Degree": "POS",
            "Gender": "Neut",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Part",
            "Voice": "Act",
        }
    },
    "Vgpa-pmanngn-p": {
        "buvusių": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Gen",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Plur",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Part",
            "Voice": "Act",
        }
    },
    "Vgpa-smanngn-p": {
        "buvusio": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Gen",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Sing",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Part",
            "Voice": "Act",
        }
    },
    "Vgpa-smannnn-p": {
        "buvęs": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Nom",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Sing",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Part",
            "Voice": "Act",
        },
        "turėjęs": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Case": "Nom",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Sing",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Part",
            "Voice": "Act",
        },
    },
    "Vgpa-smanyin-p": {
        "buvusiuoju": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Ins",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Sing",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Part",
            "Voice": "Act",
        }
    },
    "Vgpf-smpnnan-p": {
        "būsimą": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Acc",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Sing",
            "Polarity": "POS",
            "Tense": "Fut",
            "VerbForm": "Part",
            "Voice": "Pass",
        }
    },
    "Vgpf-smpnndn-p": {
        "būsimam": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Dat",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Sing",
            "Polarity": "POS",
            "Tense": "Fut",
            "VerbForm": "Part",
            "Voice": "Pass",
        }
    },
    "Vgpp--npnn-n-p": {
        "esama": {
            LEMMA: "būti",
            "POS": "VERB",
            "Degree": "POS",
            "Gender": "Neut",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Pass",
        }
    },
    "Vgpp-pfannan-p": {
        "esančias": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Acc",
            "Degree": "POS",
            "Gender": "Fem",
            "Number": "Plur",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Act",
        }
    },
    "Vgpp-pfanndn-p": {
        "turinčioms": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Case": "Dat",
            "Degree": "POS",
            "Gender": "Fem",
            "Number": "Plur",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Act",
        }
    },
    "Vgpp-pfannin-p": {
        "esančiomis": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Ins",
            "Degree": "POS",
            "Gender": "Fem",
            "Number": "Plur",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Act",
        }
    },
    "Vgpp-pfpnnan-p": {
        "daromas": {
            LEMMA: "daryti",
            "POS": "VERB",
            "Case": "Acc",
            "Degree": "POS",
            "Gender": "Fem",
            "Number": "Plur",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Pass",
        },
        "turimas": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Case": "Acc",
            "Degree": "POS",
            "Gender": "Fem",
            "Number": "Plur",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Pass",
        },
    },
    "Vgpp-pfpnnin-p": {
        "turimomis": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Case": "Ins",
            "Degree": "POS",
            "Gender": "Fem",
            "Number": "Plur",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Pass",
        }
    },
    "Vgpp-pmannan-p": {
        "turinčius": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Case": "Acc",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Plur",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Act",
        }
    },
    "Vgpp-pmanngn-p": {
        "esančių": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Gen",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Plur",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Act",
        }
    },
    "Vgpp-pmannin-p": {
        "esančiais": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Ins",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Plur",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Act",
        }
    },
    "Vgpp-pmannnn-p": {
        "esantys": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Nom",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Plur",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Act",
        }
    },
    "Vgpp-pmpnnan-p": {
        "turimus": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Case": "Acc",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Plur",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Pass",
        }
    },
    "Vgpp-pmpnngn-p": {
        "esamų": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Gen",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Plur",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Pass",
        }
    },
    "Vgpp-sfanngn-p": {
        "turinčios": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Case": "Gen",
            "Degree": "POS",
            "Gender": "Fem",
            "Number": "Sing",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Act",
        }
    },
    "Vgpp-sfannln-p": {
        "esančioje": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Loc",
            "Degree": "POS",
            "Gender": "Fem",
            "Number": "Sing",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Act",
        }
    },
    "Vgpp-sfannnn-p": {
        "esanti": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Nom",
            "Degree": "POS",
            "Gender": "Fem",
            "Number": "Sing",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Act",
        }
    },
    "Vgpp-sfpnnnn-p": {
        "daroma": {
            LEMMA: "daryti",
            "POS": "VERB",
            "Case": "Nom",
            "Degree": "POS",
            "Gender": "Fem",
            "Number": "Sing",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Pass",
        }
    },
    "Vgpp-smanngn-p": {
        "esančio": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Gen",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Sing",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Act",
        }
    },
    "Vgpp-smannnn-p": {
        "esantis": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Nom",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Sing",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Act",
        },
        "esąs": {
            LEMMA: "būti",
            "POS": "VERB",
            "Case": "Nom",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Sing",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Act",
        },
        "turintis": {
            LEMMA: "turėti",
            "POS": "VERB",
            "Case": "Nom",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Sing",
            "Polarity": "POS",
            "Tense": "Pres",
            "VerbForm": "Part",
            "Voice": "Act",
        },
    },
    "Vgps--npnn-n-p": {
        "daryta": {
            LEMMA: "daryti",
            "POS": "VERB",
            "Aspect": "Perf",
            "Degree": "POS",
            "Gender": "Neut",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Part",
            "Voice": "Pass",
        }
    },
    "Vgps-pmpnnnn-p": {
        "daryti": {
            LEMMA: "daryti",
            "POS": "VERB",
            "Aspect": "Perf",
            "Case": "Nom",
            "Degree": "POS",
            "Gender": "Masc",
            "Number": "Plur",
            "Polarity": "POS",
            "Tense": "Past",
            "VerbForm": "Part",
            "Voice": "Pass",
        }
    },
}


for tag, rules in MORPH_RULES.items():
    for key, attrs in dict(rules).items():
        rules[key.title()] = attrs



# coding: utf8
from __future__ import unicode_literals


STOP_WORDS = set(
    """
ಹಲವು
ಮೂಲಕ
ಹಾಗೂ
ಅದು
ನೀಡಿದ್ದಾರೆ
ಯಾವ
ಎಂದರು
ಅವರು
ಈಗ
ಎಂಬ
ಹಾಗಾಗಿ
ಅಷ್ಟೇ
ನಾವು
ಇದೇ
ಹೇಳಿ
ತಮ್ಮ
ಹೀಗೆ
ನಮ್ಮ
ಬೇರೆ
ನೀಡಿದರು
ಮತ್ತೆ
ಇದು
ಈ
ನೀವು
ನಾನು
ಇತ್ತು
ಎಲ್ಲಾ
ಯಾವುದೇ
ನಡೆದ
ಅದನ್ನು
ಎಂದರೆ
ನೀಡಿದೆ
ಹೀಗಾಗಿ
ಜೊತೆಗೆ
ಇದರಿಂದ
ನನಗೆ
ಅಲ್ಲದೆ
ಎಷ್ಟು
ಇದರ
ಇಲ್ಲ
ಕಳೆದ
ತುಂಬಾ
ಈಗಾಗಲೇ
ಮಾಡಿ
ಅದಕ್ಕೆ
ಬಗ್ಗೆ
ಅವರ
ಇದನ್ನು
ಆ
ಇದೆ
ಹೆಚ್ಚು
ಇನ್ನು
ಎಲ್ಲ
ಇರುವ
ಅವರಿಗೆ
ನಿಮ್ಮ
ಏನು
ಕೂಡ
ಇಲ್ಲಿ
ನನ್ನನ್ನು
ಕೆಲವು
ಮಾತ್ರ
ಬಳಿಕ
ಅಂತ
ತನ್ನ
ಆಗ
ಅಥವಾ
ಅಲ್ಲ
ಕೇವಲ
ಆದರೆ
ಮತ್ತು
ಇನ್ನೂ
ಅದೇ
ಆಗಿ
ಅವರನ್ನು
ಹೇಳಿದ್ದಾರೆ
ನಡೆದಿದೆ
ಇದಕ್ಕೆ
ಎಂಬುದು
ಎಂದು
ನನ್ನ
ಮೇಲೆ
""".split()
)



# coding: utf-8
from __future__ import unicode_literals

from numpy.testing import assert_almost_equal, assert_array_almost_equal
import pytest
from pytest import approx
from spacy.gold import GoldParse
from spacy.scorer import Scorer, ROCAUCScore
from spacy.scorer import _roc_auc_score, _roc_curve
from .util import get_doc

test_las_apple = [
    [
        "Apple is looking at buying U.K. startup for $ 1 billion",
        {
            "heads": [2, 2, 2, 2, 3, 6, 4, 4, 10, 10, 7],
            "deps": [
                "nsubj",
                "aux",
                "ROOT",
                "prep",
                "pcomp",
                "compound",
                "dobj",
                "prep",
                "quantmod",
                "compound",
                "pobj",
            ],
        },
    ]
]

test_ner_cardinal = [
    ["100 - 200", {"entities": [[0, 3, "CARDINAL"], [6, 9, "CARDINAL"]]}]
]

test_ner_apple = [
    [
        "Apple is looking at buying U.K. startup for $1 billion",
        {"entities": [(0, 5, "ORG"), (27, 31, "GPE"), (44, 54, "MONEY")]},
    ]
]


def test_las_per_type(en_vocab):
    # Gold and Doc are identical
    scorer = Scorer()
    for input_, annot in test_las_apple:
        doc = get_doc(
            en_vocab,
            words=input_.split(" "),
            heads=([h - i for i, h in enumerate(annot["heads"])]),
            deps=annot["deps"],
        )
        gold = GoldParse(doc, heads=annot["heads"], deps=annot["deps"])
        scorer.score(doc, gold)
    results = scorer.scores

    assert results["uas"] == 100
    assert results["las"] == 100
    assert results["las_per_type"]["nsubj"]["p"] == 100
    assert results["las_per_type"]["nsubj"]["r"] == 100
    assert results["las_per_type"]["nsubj"]["f"] == 100
    assert results["las_per_type"]["compound"]["p"] == 100
    assert results["las_per_type"]["compound"]["r"] == 100
    assert results["las_per_type"]["compound"]["f"] == 100

    # One dep is incorrect in Doc
    scorer = Scorer()
    for input_, annot in test_las_apple:
        doc = get_doc(
            en_vocab,
            words=input_.split(" "),
            heads=([h - i for i, h in enumerate(annot["heads"])]),
            deps=annot["deps"],
        )
        gold = GoldParse(doc, heads=annot["heads"], deps=annot["deps"])
        doc[0].dep_ = "compound"
        scorer.score(doc, gold)
    results = scorer.scores

    assert results["uas"] == 100
    assert_almost_equal(results["las"], 90.9090909)
    assert results["las_per_type"]["nsubj"]["p"] == 0
    assert results["las_per_type"]["nsubj"]["r"] == 0
    assert results["las_per_type"]["nsubj"]["f"] == 0
    assert_almost_equal(results["las_per_type"]["compound"]["p"], 66.6666666)
    assert results["las_per_type"]["compound"]["r"] == 100
    assert results["las_per_type"]["compound"]["f"] == 80


def test_ner_per_type(en_vocab):
    # Gold and Doc are identical
    scorer = Scorer()
    for input_, annot in test_ner_cardinal:
        doc = get_doc(
            en_vocab,
            words=input_.split(" "),
            ents=[[0, 1, "CARDINAL"], [2, 3, "CARDINAL"]],
        )
        gold = GoldParse(doc, entities=annot["entities"])
        scorer.score(doc, gold)
    results = scorer.scores

    assert results["ents_p"] == 100
    assert results["ents_f"] == 100
    assert results["ents_r"] == 100
    assert results["ents_per_type"]["CARDINAL"]["p"] == 100
    assert results["ents_per_type"]["CARDINAL"]["f"] == 100
    assert results["ents_per_type"]["CARDINAL"]["r"] == 100

    # Doc has one missing and one extra entity
    # Entity type MONEY is not present in Doc
    scorer = Scorer()
    for input_, annot in test_ner_apple:
        doc = get_doc(
            en_vocab,
            words=input_.split(" "),
            ents=[[0, 1, "ORG"], [5, 6, "GPE"], [6, 7, "ORG"]],
        )
        gold = GoldParse(doc, entities=annot["entities"])
        scorer.score(doc, gold)
    results = scorer.scores

    assert results["ents_p"] == approx(66.66666)
    assert results["ents_r"] == approx(66.66666)
    assert results["ents_f"] == approx(66.66666)
    assert "GPE" in results["ents_per_type"]
    assert "MONEY" in results["ents_per_type"]
    assert "ORG" in results["ents_per_type"]
    assert results["ents_per_type"]["GPE"]["p"] == 100
    assert results["ents_per_type"]["GPE"]["r"] == 100
    assert results["ents_per_type"]["GPE"]["f"] == 100
    assert results["ents_per_type"]["MONEY"]["p"] == 0
    assert results["ents_per_type"]["MONEY"]["r"] == 0
    assert results["ents_per_type"]["MONEY"]["f"] == 0
    assert results["ents_per_type"]["ORG"]["p"] == 50
    assert results["ents_per_type"]["ORG"]["r"] == 100
    assert results["ents_per_type"]["ORG"]["f"] == approx(66.66666)


def test_roc_auc_score():
    # Binary classification, toy tests from scikit-learn test suite
    y_true = [0, 1]
    y_score = [0, 1]
    tpr, fpr, _ = _roc_curve(y_true, y_score)
    roc_auc = _roc_auc_score(y_true, y_score)
    assert_array_almost_equal(tpr, [0, 0, 1])
    assert_array_almost_equal(fpr, [0, 1, 1])
    assert_almost_equal(roc_auc, 1.0)

    y_true = [0, 1]
    y_score = [1, 0]
    tpr, fpr, _ = _roc_curve(y_true, y_score)
    roc_auc = _roc_auc_score(y_true, y_score)
    assert_array_almost_equal(tpr, [0, 1, 1])
    assert_array_almost_equal(fpr, [0, 0, 1])
    assert_almost_equal(roc_auc, 0.0)

    y_true = [1, 0]
    y_score = [1, 1]
    tpr, fpr, _ = _roc_curve(y_true, y_score)
    roc_auc = _roc_auc_score(y_true, y_score)
    assert_array_almost_equal(tpr, [0, 1])
    assert_array_almost_equal(fpr, [0, 1])
    assert_almost_equal(roc_auc, 0.5)

    y_true = [1, 0]
    y_score = [1, 0]
    tpr, fpr, _ = _roc_curve(y_true, y_score)
    roc_auc = _roc_auc_score(y_true, y_score)
    assert_array_almost_equal(tpr, [0, 0, 1])
    assert_array_almost_equal(fpr, [0, 1, 1])
    assert_almost_equal(roc_auc, 1.0)

    y_true = [1, 0]
    y_score = [0.5, 0.5]
    tpr, fpr, _ = _roc_curve(y_true, y_score)
    roc_auc = _roc_auc_score(y_true, y_score)
    assert_array_almost_equal(tpr, [0, 1])
    assert_array_almost_equal(fpr, [0, 1])
    assert_almost_equal(roc_auc, 0.5)

    # same result as above with ROCAUCScore wrapper
    score = ROCAUCScore()
    score.score_set(0.5, 1)
    score.score_set(0.5, 0)
    assert_almost_equal(score.score, 0.5)

    # check that errors are raised in undefined cases and score is -inf
    y_true = [0, 0]
    y_score = [0.25, 0.75]
    with pytest.raises(ValueError):
        _roc_auc_score(y_true, y_score)

    score = ROCAUCScore()
    score.score_set(0.25, 0)
    score.score_set(0.75, 0)
    assert score.score == -float("inf")

    y_true = [1, 1]
    y_score = [0.25, 0.75]
    with pytest.raises(ValueError):
        _roc_auc_score(y_true, y_score)

    score = ROCAUCScore()
    score.score_set(0.25, 1)
    score.score_set(0.75, 1)
    assert score.score == -float("inf")



# coding: utf8
from __future__ import unicode_literals


"""
Example sentences to test spaCy and its language models.

>>> from spacy.lang.pl.examples import sentences
>>> docs = nlp.pipe(sentences)
"""


sentences = [
    "Poczuł przyjemną woń mocnej kawy.",
    "Istnieje wiele dróg oddziaływania substancji psychoaktywnej na układ nerwowy.",
    "Powitał mnie biało-czarny kot, płosząc siedzące na płocie trzy dorodne dudki.",
    "Nowy abonament pod lupą Komisji Europejskiej",
    "Czy w ciągu ostatnich 48 godzin spożyłeś leki zawierające paracetamol?",
    "Kto ma ochotę zapoznać się z innymi niż w książkach przygodami Muminków i ich przyjaciół, temu polecam komiks Tove Jansson „Muminki i morze”.",
]



# coding: utf8
from __future__ import unicode_literals

from ...symbols import LEMMA, NORM, ORTH, PRON_LEMMA

_exc = {}


# Verbs

for verb_data in [
    {ORTH: "driver"},
    {ORTH: "kör"},
    {ORTH: "hörr", LEMMA: "hör"},
    {ORTH: "fattar"},
    {ORTH: "hajar", LEMMA: "förstår"},
    {ORTH: "lever"},
    {ORTH: "serr", LEMMA: "ser"},
    {ORTH: "fixar"},
]:
    verb_data_tc = dict(verb_data)
    verb_data_tc[ORTH] = verb_data_tc[ORTH].title()
    for data in [verb_data, verb_data_tc]:
        _exc[data[ORTH] + "u"] = [
            dict(data),
            {ORTH: "u", LEMMA: PRON_LEMMA, NORM: "du"},
        ]

# Abbreviations for weekdays "sön." (for "söndag" / "söner")
# are left out because they are ambiguous. The same is the case
# for abbreviations "jul." and "Jul." ("juli" / "jul").
for exc_data in [
    {ORTH: "jan.", LEMMA: "januari"},
    {ORTH: "febr.", LEMMA: "februari"},
    {ORTH: "feb.", LEMMA: "februari"},
    {ORTH: "apr.", LEMMA: "april"},
    {ORTH: "jun.", LEMMA: "juni"},
    {ORTH: "aug.", LEMMA: "augusti"},
    {ORTH: "sept.", LEMMA: "september"},
    {ORTH: "sep.", LEMMA: "september"},
    {ORTH: "okt.", LEMMA: "oktober"},
    {ORTH: "nov.", LEMMA: "november"},
    {ORTH: "dec.", LEMMA: "december"},
    {ORTH: "mån.", LEMMA: "måndag"},
    {ORTH: "tis.", LEMMA: "tisdag"},
    {ORTH: "ons.", LEMMA: "onsdag"},
    {ORTH: "tors.", LEMMA: "torsdag"},
    {ORTH: "fre.", LEMMA: "fredag"},
    {ORTH: "lör.", LEMMA: "lördag"},
    {ORTH: "Jan.", LEMMA: "Januari"},
    {ORTH: "Febr.", LEMMA: "Februari"},
    {ORTH: "Feb.", LEMMA: "Februari"},
    {ORTH: "Apr.", LEMMA: "April"},
    {ORTH: "Jun.", LEMMA: "Juni"},
    {ORTH: "Aug.", LEMMA: "Augusti"},
    {ORTH: "Sept.", LEMMA: "September"},
    {ORTH: "Sep.", LEMMA: "September"},
    {ORTH: "Okt.", LEMMA: "Oktober"},
    {ORTH: "Nov.", LEMMA: "November"},
    {ORTH: "Dec.", LEMMA: "December"},
    {ORTH: "Mån.", LEMMA: "Måndag"},
    {ORTH: "Tis.", LEMMA: "Tisdag"},
    {ORTH: "Ons.", LEMMA: "Onsdag"},
    {ORTH: "Tors.", LEMMA: "Torsdag"},
    {ORTH: "Fre.", LEMMA: "Fredag"},
    {ORTH: "Lör.", LEMMA: "Lördag"},
    {ORTH: "sthlm", LEMMA: "Stockholm"},
    {ORTH: "gbg", LEMMA: "Göteborg"},
]:
    _exc[exc_data[ORTH]] = [exc_data]


# Specific case abbreviations only
for orth in ["AB", "Dr.", "H.M.", "H.K.H.", "m/s", "M/S", "Ph.d.", "S:t", "s:t"]:
    _exc[orth] = [{ORTH: orth}]


ABBREVIATIONS = [
    "ang",
    "anm",
    "bl.a",
    "d.v.s",
    "doc",
    "dvs",
    "e.d",
    "e.kr",
    "el.",
    "eng",
    "etc",
    "exkl",
    "ev",
    "f.",
    "f.d",
    "f.kr",
    "f.n",
    "f.ö",
    "fid",
    "fig",
    "forts",
    "fr.o.m",
    "förf",
    "inkl",
    "iofs",
    "jur.",
    "kap",
    "kl",
    "kor.",
    "kr",
    "kungl",
    "lat",
    "m.a.o",
    "m.fl",
    "m.m",
    "max",
    "milj",
    "min.",
    "mos",
    "mt",
    "mvh",
    "o.d",
    "o.s.v",
    "obs",
    "osv",
    "p.g.a",
    "proc",
    "prof",
    "ref",
    "resp",
    "s.a.s",
    "s.k",
    "s.t",
    "sid",
    "t.ex",
    "t.h",
    "t.o.m",
    "t.v",
    "tel",
    "ung.",
    "vol",
    "v.",
    "äv",
    "övers",
]

# Add abbreviation for trailing punctuation too. If the abbreviation already has a trailing punctuation - skip it.
for abbr in ABBREVIATIONS:
    if not abbr.endswith("."):
        ABBREVIATIONS.append(abbr + ".")

for orth in ABBREVIATIONS:
    _exc[orth] = [{ORTH: orth}]
    capitalized = orth.capitalize()
    _exc[capitalized] = [{ORTH: capitalized}]

# Sentences ending in "i." (as in "... peka i."), "m." (as in "...än 2000 m."),
# should be tokenized as two separate tokens.
for orth in ["i", "m"]:
    _exc[orth + "."] = [{ORTH: orth, LEMMA: orth, NORM: orth}, {ORTH: "."}]

TOKENIZER_EXCEPTIONS = _exc



# coding: utf8
from __future__ import unicode_literals

from spacy.tokens import Doc

import numpy as np


def test_issue3540(en_vocab):

    words = ["I", "live", "in", "NewYork", "right", "now"]
    tensor = np.asarray(
        [[1.0, 1.1], [2.0, 2.1], [3.0, 3.1], [4.0, 4.1], [5.0, 5.1], [6.0, 6.1]],
        dtype="f",
    )
    doc = Doc(en_vocab, words=words)
    doc.tensor = tensor

    gold_text = ["I", "live", "in", "NewYork", "right", "now"]
    assert [token.text for token in doc] == gold_text

    gold_lemma = ["I", "live", "in", "NewYork", "right", "now"]
    assert [token.lemma_ for token in doc] == gold_lemma

    vectors_1 = [token.vector for token in doc]
    assert len(vectors_1) == len(doc)

    with doc.retokenize() as retokenizer:
        heads = [(doc[3], 1), doc[2]]
        attrs = {"POS": ["PROPN", "PROPN"], "DEP": ["pobj", "compound"]}
        retokenizer.split(doc[3], ["New", "York"], heads=heads, attrs=attrs)

    gold_text = ["I", "live", "in", "New", "York", "right", "now"]
    assert [token.text for token in doc] == gold_text

    gold_lemma = ["I", "live", "in", "New", "York", "right", "now"]
    assert [token.lemma_ for token in doc] == gold_lemma

    vectors_2 = [token.vector for token in doc]
    assert len(vectors_2) == len(doc)

    assert vectors_1[0].tolist() == vectors_2[0].tolist()
    assert vectors_1[1].tolist() == vectors_2[1].tolist()
    assert vectors_1[2].tolist() == vectors_2[2].tolist()

    assert vectors_1[4].tolist() == vectors_2[5].tolist()
    assert vectors_1[5].tolist() == vectors_2[6].tolist()



# coding: utf8
from __future__ import unicode_literals

from ...attrs import LIKE_NUM


_num_words = [
    "zero",
    "un",
    "dos",
    "tres",
    "quatre",
    "cinc",
    "sis",
    "set",
    "vuit",
    "nou",
    "deu",
    "onze",
    "dotze",
    "tretze",
    "catorze",
    "quinze",
    "setze",
    "disset",
    "divuit",
    "dinou",
    "vint",
    "trenta",
    "quaranta",
    "cinquanta",
    "seixanta",
    "setanta",
    "vuitanta",
    "noranta",
    "cent",
    "mil",
    "milió",
    "bilió",
    "trilió",
    "quatrilió",
    "gazilió",
    "bazilió",
]


def like_num(text):
    if text.startswith(("+", "-", "±", "~")):
        text = text[1:]
    text = text.replace(",", "").replace(".", "")
    if text.isdigit():
        return True
    if text.count("/") == 1:
        num, denom = text.split("/")
        if num.isdigit() and denom.isdigit():
            return True
    if text in _num_words:
        return True
    return False


LEX_ATTRS = {LIKE_NUM: like_num}



# encoding: utf8
from __future__ import unicode_literals

# Source: Handpicked by Jens Dahl Møllerhøj.

STOP_WORDS = set(
    """
af aldrig alene alle allerede alligevel alt altid anden andet andre at

bag begge blandt blev blive bliver burde bør

da de dem den denne dens der derefter deres derfor derfra deri dermed derpå derved det dette dig din dine disse dog du

efter egen eller ellers en end endnu ene eneste enhver ens enten er et

flere flest fleste for foran fordi forrige fra få før først

gennem gjorde gjort god gør gøre gørende

ham han hans har havde have hel heller hen hende hendes henover her herefter heri hermed herpå hun hvad hvem hver hvilke hvilken hvilkes hvis hvor hvordan hvorefter hvorfor hvorfra hvorhen hvori hvorimod hvornår hvorved

i igen igennem ikke imellem imens imod ind indtil ingen intet

jeg jer jeres jo

kan kom kommer kun kunne

lad langs lav lave lavet lidt lige ligesom lille længere

man mange med meget mellem men mens mere mest mig min mindre mindst mine mit må måske

ned nemlig nogen nogensinde noget nogle nok nu ny nyt nær næste næsten

og også om omkring op os over overalt

på

samme sammen selv selvom senere ses siden sig sige skal skulle som stadig synes syntes så sådan således

temmelig tidligere til tilbage tit

ud uden udover under undtagen

var ved vi via vil ville vore vores vær være været

øvrigt
""".split()
)



# encoding: utf8
from __future__ import unicode_literals

from ...symbols import POS, ADJ, AUX, DET, PART, PRON, SPACE ,X

# mapping from tag bi-gram to pos of previous token
TAG_ORTH_MAP = {
    "空白": {
        " ": SPACE,
        "　": X,
    },
    "助詞-副助詞": {
        "たり": PART,
    },
    "連体詞": {
        "あの": DET,
        "かの": DET,
        "この": DET,
        "その": DET,
        "どの": DET,
        "彼の": DET,
        "此の": DET,
        "其の": DET,
        "ある": PRON,
        "こんな": PRON,
        "そんな": PRON,
        "どんな": PRON,
        "あらゆる": PRON,
    },
}



# coding: utf-8
# cython: profile=True
# cython: infer_types=True
"""Implements the projectivize/deprojectivize mechanism in Nivre & Nilsson 2005
for doing pseudo-projective parsing implementation uses the HEAD decoration
scheme.
"""
from __future__ import unicode_literals

from copy import copy

from ..tokens.doc cimport Doc, set_children_from_heads
from ..errors import Errors


DELIMITER = '||'


def ancestors(tokenid, heads):
    # Returns all words going from the word up the path to the root. The path
    # to root cannot be longer than the number of words in the  sentence. This
    # function ends after at most len(heads) steps, because it would otherwise
    # loop indefinitely on cycles.
    head = tokenid
    cnt = 0
    while heads[head] != head and cnt < len(heads):
        head = heads[head]
        cnt += 1
        yield head
        if head is None:
            break


def contains_cycle(heads):
    # in an acyclic tree, the path from each word following the head relation
    # upwards always ends at the root node
    for tokenid in range(len(heads)):
        seen = set([tokenid])
        for ancestor in ancestors(tokenid, heads):
            if ancestor in seen:
                return seen
            seen.add(ancestor)
    return None


def is_nonproj_arc(tokenid, heads):
    # definition (e.g. Havelka 2007): an arc h -> d, h < d is non-projective
    # if there is a token k, h < k < d such that h is not
    # an ancestor of k. Same for h -> d, h > d
    head = heads[tokenid]
    if head == tokenid:  # root arcs cannot be non-projective
        return False
    elif head is None:  # unattached tokens cannot be non-projective
        return False

    start, end = (head+1, tokenid) if head < tokenid else (tokenid+1, head)
    for k in range(start, end):
        for ancestor in ancestors(k, heads):
            if ancestor is None:  # for unattached tokens/subtrees
                break
            elif ancestor == head:  # normal case: k dominated by h
                break
        else:  # head not in ancestors: d -> h is non-projective
            return True
    return False


def is_nonproj_tree(heads):
    # a tree is non-projective if at least one arc is non-projective
    return any(is_nonproj_arc(word, heads) for word in range(len(heads)))


def decompose(label):
    return label.partition(DELIMITER)[::2]


def is_decorated(label):
    return DELIMITER in label

def count_decorated_labels(gold_tuples):
    freqs = {}
    for raw_text, sents in gold_tuples:
        for (ids, words, tags, heads, labels, iob), ctnts in sents:
            proj_heads, deco_labels = projectivize(heads, labels)
            # set the label to ROOT for each root dependent
            deco_labels = ['ROOT' if head == i else deco_labels[i]
                           for i, head in enumerate(proj_heads)]
            # count label frequencies
            for label in deco_labels:
                if is_decorated(label):
                    freqs[label] = freqs.get(label, 0) + 1
    return freqs


def preprocess_training_data(gold_tuples, label_freq_cutoff=30):
    preprocessed = []
    freqs = {}
    for raw_text, sents in gold_tuples:
        prepro_sents = []
        for (ids, words, tags, heads, labels, iob), ctnts in sents:
            proj_heads, deco_labels = projectivize(heads, labels)
            # set the label to ROOT for each root dependent
            deco_labels = ['ROOT' if head == i else deco_labels[i]
                           for i, head in enumerate(proj_heads)]
            # count label frequencies
            if label_freq_cutoff > 0:
                for label in deco_labels:
                    if is_decorated(label):
                        freqs[label] = freqs.get(label, 0) + 1
            prepro_sents.append(
                ((ids, words, tags, proj_heads, deco_labels, iob), ctnts))
        preprocessed.append((raw_text, prepro_sents))
    if label_freq_cutoff > 0:
        return _filter_labels(preprocessed, label_freq_cutoff, freqs)
    return preprocessed


def projectivize(heads, labels):
    # Use the algorithm by Nivre & Nilsson 2005. Assumes heads to be a proper
    # tree, i.e. connected and cycle-free. Returns a new pair (heads, labels)
    # which encode a projective and decorated tree.
    proj_heads = copy(heads)
    smallest_np_arc = _get_smallest_nonproj_arc(proj_heads)
    if smallest_np_arc is None:  # this sentence is already projective
        return proj_heads, copy(labels)
    while smallest_np_arc is not None:
        _lift(smallest_np_arc, proj_heads)
        smallest_np_arc = _get_smallest_nonproj_arc(proj_heads)
    deco_labels = _decorate(heads, proj_heads, labels)
    return proj_heads, deco_labels


cpdef deprojectivize(Doc doc):
    # Reattach arcs with decorated labels (following HEAD scheme). For each
    # decorated arc X||Y, search top-down, left-to-right, breadth-first until
    # hitting a Y then make this the new head.
    for i in range(doc.length):
        label = doc.vocab.strings[doc.c[i].dep]
        if DELIMITER in label:
            new_label, head_label = label.split(DELIMITER)
            new_head = _find_new_head(doc[i], head_label)
            doc.c[i].head = new_head.i - i
            doc.c[i].dep = doc.vocab.strings.add(new_label)
    set_children_from_heads(doc.c, doc.length)
    return doc


def _decorate(heads, proj_heads, labels):
    # uses decoration scheme HEAD from Nivre & Nilsson 2005
    if (len(heads) != len(proj_heads)) or (len(proj_heads) != len(labels)):
        raise ValueError(Errors.E082.format(n_heads=len(heads),
                                            n_proj_heads=len(proj_heads),
                                            n_labels=len(labels)))
    deco_labels = []
    for tokenid, head in enumerate(heads):
        if head != proj_heads[tokenid]:
            deco_labels.append(
                '%s%s%s' % (labels[tokenid], DELIMITER, labels[head]))
        else:
            deco_labels.append(labels[tokenid])
    return deco_labels


def _get_smallest_nonproj_arc(heads):
    # return the smallest non-proj arc or None
    # where size is defined as the distance between dep and head
    # and ties are broken left to right
    smallest_size = float('inf')
    smallest_np_arc = None
    for tokenid, head in enumerate(heads):
        size = abs(tokenid-head)
        if size < smallest_size and is_nonproj_arc(tokenid, heads):
            smallest_size = size
            smallest_np_arc = tokenid
    return smallest_np_arc


def _lift(tokenid, heads):
    # reattaches a word to it's grandfather
    head = heads[tokenid]
    ghead = heads[head]
    # attach to ghead if head isn't attached to root else attach to root
    heads[tokenid] = ghead if head != ghead else tokenid


def _find_new_head(token, headlabel):
    # search through the tree starting from the head of the given token
    # returns the id of the first descendant with the given label
    # if there is none, return the current head (no change)
    queue = [token.head]
    while queue:
        next_queue = []
        for qtoken in queue:
            for child in qtoken.children:
                if child.is_space:
                    continue
                if child == token:
                    continue
                if child.dep_ == headlabel:
                    return child
                next_queue.append(child)
        queue = next_queue
    return token.head


def _filter_labels(gold_tuples, cutoff, freqs):
    # throw away infrequent decorated labels
    # can't learn them reliably anyway and keeps label set smaller
    filtered = []
    for raw_text, sents in gold_tuples:
        filtered_sents = []
        for (ids, words, tags, heads, labels, iob), ctnts in sents:
            filtered_labels = []
            for label in labels:
                if is_decorated(label) and freqs.get(label, 0) < cutoff:
                    filtered_labels.append(decompose(label)[0])
                else:
                    filtered_labels.append(label)
            filtered_sents.append(
                ((ids, words, tags, heads, filtered_labels, iob), ctnts))
        filtered.append((raw_text, filtered_sents))
    return filtered



# coding: utf8
from __future__ import unicode_literals

STOP_WORDS = set(
    """
이
있
하
것
들
그
되
수
이
보
않
없
나
주
아니
등
같
때
년
가
한
지
오
말
일
그렇
위하
때문
그것
두
말하
알
그러나
받
못하
일
그런
또
더
많
그리고
좋
크
시키
그러
하나
살
데
안
어떤
번
나
다른
어떻
들
이렇
점
싶
말
좀
원
잘
놓
""".split()
)



# coding: utf8
from __future__ import unicode_literals

from .stop_words import STOP_WORDS

from ..tokenizer_exceptions import BASE_EXCEPTIONS
from .lex_attrs import LEX_ATTRS
from ...language import Language
from ...attrs import LANG
from ...util import update_exc


class HebrewDefaults(Language.Defaults):
    lex_attr_getters = dict(Language.Defaults.lex_attr_getters)
    lex_attr_getters.update(LEX_ATTRS)
    lex_attr_getters[LANG] = lambda text: "he"
    tokenizer_exceptions = update_exc(BASE_EXCEPTIONS)
    stop_words = STOP_WORDS
    writing_system = {"direction": "rtl", "has_case": False, "has_letters": True}


class Hebrew(Language):
    lang = "he"
    Defaults = HebrewDefaults


__all__ = ["Hebrew"]



# coding: utf8
from __future__ import unicode_literals


"""
Example sentences to test spaCy and its language models.

>>> from spacy.lang.nl.examples import sentences
>>> docs = nlp.pipe(sentences)
"""


sentences = [
    "Apple overweegt om voor 1 miljard een U.K. startup te kopen",
    "Autonome auto's verschuiven de verzekeringverantwoordelijkheid naar producenten",
    "San Francisco overweegt robots op voetpaden te verbieden",
    "Londen is een grote stad in het Verenigd Koninkrijk",
]
